@@ -58,17 +58,16 @@ mod handshake;
 ))]
 pub mod stream;
 
-use std::io::{Read, Write};
+use std::{
+    io::{Read, Write},
+    pin::Pin,
+    task::{ready, Context, Poll},
+};
 
 use compat::{cvt, AllowStd, ContextWaker};
+use futures_core::stream::{FusedStream, Stream};
 use futures_io::{AsyncRead, AsyncWrite};
-use futures_util::{
-    sink::{Sink, SinkExt},
-    stream::{FusedStream, Stream},
-};
 use log::*;
-use std::pin::Pin;
-use std::task::{Context, Poll};
 
 #[cfg(feature = "handshake")]
 use tungstenite::{
@@ -227,6 +226,7 @@ where
 #[derive(Debug)]
 pub struct WebSocketStream<S> {
     inner: WebSocket<AllowStd<S>>,
+    #[cfg(feature = "futures-03-sink")]
     closing: bool,
     ended: bool,
     /// Tungstenite is probably ready to receive more data.
@@ -269,6 +269,7 @@ impl<S> WebSocketStream<S> {
     pub(crate) fn new(ws: WebSocket<AllowStd<S>>) -> Self {
         Self {
             inner: ws,
+            #[cfg(feature = "futures-03-sink")]
             closing: false,
             ended: false,
             ready: true,
@@ -337,7 +338,7 @@ where
             return Poll::Ready(None);
         }
 
-        match futures_util::ready!(self.with_context(Some((ContextWaker::Read, cx)), |s| {
+        match ready!(self.with_context(Some((ContextWaker::Read, cx)), |s| {
             #[cfg(feature = "verbose-logging")]
             trace!(
                 "{}:{} Stream.with_context poll_next -> read()",
@@ -368,7 +369,8 @@ where
     }
 }
 
-impl<T> Sink<Message> for WebSocketStream<T>
+#[cfg(feature = "futures-03-sink")]
+impl<T> futures_util::Sink<Message> for WebSocketStream<T>
 where
     T: AsyncRead + AsyncWrite + Unpin,
 {
@@ -446,6 +448,84 @@ where
     }
 }
 
+impl<S> WebSocketStream<S> {
+    /// Simple send method to replace `futures_sink::Sink` (till v0.3).
+    pub async fn send(&mut self, msg: Message) -> Result<(), WsError>
+    where
+        S: AsyncRead + AsyncWrite + Unpin,
+    {
+        Send::new(self, msg).await
+    }
+}
+
+struct Send<'a, S> {
+    ws: &'a mut WebSocketStream<S>,
+    msg: Option<Message>,
+}
+
+impl<'a, S> Send<'a, S>
+where
+    S: AsyncRead + AsyncWrite + Unpin,
+{
+    fn new(ws: &'a mut WebSocketStream<S>, msg: Message) -> Self {
+        Self { ws, msg: Some(msg) }
+    }
+}
+
+impl<S> std::future::Future for Send<'_, S>
+where
+    S: AsyncRead + AsyncWrite + Unpin,
+{
+    type Output = Result<(), WsError>;
+
+    fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
+        if self.msg.is_some() {
+            if !self.ws.ready {
+                // Currently blocked so try to flush the blockage away
+                let polled = self
+                    .ws
+                    .with_context(Some((ContextWaker::Write, cx)), |s| cvt(s.flush()))
+                    .map(|r| {
+                        self.ws.ready = true;
+                        r
+                    });
+                ready!(polled)?
+            }
+
+            let msg = self.msg.take().expect("unreachable");
+            match self.ws.with_context(None, |s| s.write(msg)) {
+                Ok(_) => Ok(()),
+                Err(WsError::Io(err)) if err.kind() == std::io::ErrorKind::WouldBlock => {
+                    // the message was accepted and queued so not an error
+                    //
+                    // set to false here for cancellation safety of *this* Future
+                    self.ws.ready = false;
+                    Ok(())
+                }
+                Err(e) => {
+                    debug!("websocket start_send error: {}", e);
+                    Err(e)
+                }
+            }?;
+        }
+
+        let polled = self
+            .ws
+            .with_context(Some((ContextWaker::Write, cx)), |s| cvt(s.flush()))
+            .map(|r| {
+                self.ws.ready = true;
+                match r {
+                    // WebSocket connection has just been closed. Flushing completed, not an error.
+                    Err(WsError::ConnectionClosed) => Ok(()),
+                    other => other,
+                }
+            });
+        ready!(polled)?;
+
+        Poll::Ready(Ok(()))
+    }
+}
+
 #[cfg(any(
     feature = "async-tls",
     feature = "async-std-runtime",
